@@ -44,6 +44,10 @@ from requests.auth import HTTPBasicAuth
 from c8ylp.rest_client.sessions import BaseUrlSession
 
 
+class CumulocityError(Exception):
+    """Cumulocity error"""
+
+
 class CumulocityMissingTFAToken(Exception):
     """Cumulocity missing TFA token"""
 
@@ -128,7 +132,6 @@ class CumulocityClient:
             login_options_body = json.loads(response.content.decode("utf-8"))
             login_options = login_options_body.get("loginOptions", {})
             for option in login_options:
-
                 # Check if oAuth is supported
                 if option.get("type") in ("OAUTH2_INTERNAL", "OAUTH2"):
                     self._supports_oauth = True
@@ -359,7 +362,7 @@ class CumulocityClient:
         mor_id = ext_id.get("managedObject", {}).get("id")
 
         if not mor_id:
-            raise Exception("Managed object id is empty")
+            raise CumulocityError("Managed object id is empty")
 
         response = self.session.get(f"/inventory/managedObjects/{mor_id}")
         if response.status_code == 200:
